@@ -3,6 +3,8 @@ import json
 import time
 
 import aiohttp
+import async_timeout
+# from fake_useragent import UserAgent
 
 
 class Roster():
@@ -48,13 +50,14 @@ class Roster():
 
         Attention: 并不会对searchMsg的格式进行检索或抛出异常。
         """
+        # self.UserAgent = UserAgent()
         self.LiveRoomList = []
         self.SearchMsg = searchMsg
         self.EventLoop = asyncio.get_event_loop()
         self.Flags = dict(
             zip([d['name'] for d in self.SearchMsg['targets']], len(self.SearchMsg['targets'])*[1000]))
 
-    def Loads(self, basePage=1, topPage=3, headers=None) -> str:
+    def Loads(self, basePage=1, topPage=3) -> str:
         """ 加载容器内容的函数
         函数解析SearchMsg的内容，并按页面（即30个直播间一组）来分配任务列表到事件循环中。
 
@@ -79,27 +82,26 @@ class Roster():
             targets = self.SearchMsg.get('targets')
         except:
             raise KeyError
-        # 循环构筑协程
         taskList = []
         for target in targets:
             maxPage = self.Flags.get(target.get('name'))
             for page in range(basePage, topPage+1):
                 if page <= maxPage:
                     taskList.append(self.EventLoop.create_task(
-                        self.LoadPage(target, page, keyWord, headers)))
+                        self.LoadPage(target, page, keyWord)))
                 else:
                     pass
         if len(taskList) != 0:
             self.EventLoop.run_until_complete(asyncio.wait(taskList))
 
-    def LoadAll(self, step=50, headers=None):
+    def LoadAll(self, step=50):
         continueable = True
         page = 1
         while continueable:
             for key in self.Flags:
                 continueable = continueable and (page >= self.Flags[key])
             continueable = not continueable
-            self.Loads(basePage=page, topPage=page+step, headers=headers)
+            self.Loads(basePage=page, topPage=page+step)
             page = page+step+1
 
     def Push(self, roomId: str, ruId: str, parentId: str, areaId: str, url: str) -> dict:
@@ -113,19 +115,25 @@ class Roster():
         self.LiveRoomList.append(dic)
         return dic
 
-    async def LoadPage(self, target: dict, page: int, keyWord: str, headers: dict):
+    async def LoadPage(self, target: dict, page: int, keyWord: str):
         response = {}
         try:
             url = target.get('url') % (page)
         except:
             raise KeyError
-        async with aiohttp.ClientSession() as session:
-            async with session.get(url, headers=headers) as res:
-                # 请求成功则拉取Json报文。
-                if res.status == 200:
-                    response = json.loads(await res.text())
-                else:
-                    return False
+        # headers = {'User-Agent': self.UserAgent.random}
+        headers = None
+        try:
+            with async_timeout.timeout(10):
+                async with aiohttp.ClientSession() as session:
+                    async with session.get(url, headers=headers) as res:
+                        # 请求成功则拉取Json报文。
+                        if res.status == 200:
+                            response = json.loads(await res.text())
+                        else:
+                            return False
+        except asyncio.TimeoutError as e:
+            return False
         roomList = response.get('data').get('list')
         # 如果超过了最大页数，接收的roomList的长度则为0。
         if len(roomList) == 0:
@@ -179,17 +187,17 @@ def log(file, score: int, roomid: str, msg: str, success=0):
         raise KeyError
 
 
-def createHeaders(userAgent: str, cookie: str):
+def createHeaders(cookie: str):
     return {
         "Host": "api.live.bilibili.com",
-        "User-Agent": userAgent,
+        "User-Agent": "",
         "Accept": "application/json, text/plain, */*",
         "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
         "Accept-Encoding": "gzip, deflate, br",
         "Content-Type": "application/x-www-form-urlencoded",
         "Content-Length": "",
         "Origin": "https://live.bilibili.com",
-        "Connection": "keep-alive",
+        # "Connection": "keep-alive",
         "Referer": "",
         "Cookie": cookie
     }
