@@ -1,4 +1,12 @@
-__version__ = "2020.4.7"
+'''
+@Author: Hata
+@Date: 2020-03-31 14:06:04
+@LastEditors: Hata
+@LastEditTime: 2020-05-21 21:00:36
+@FilePath: \DD-Emblem\ddemblem\__init__.py
+@Description: 
+'''
+__version__ = "2020.5.21"
 
 from ddemblem.Base import Roster as Roster
 from ddemblem.Base import createHeaders as CreateHeaders
